% Magnitude and Symmetric Optimum Design for DC-motor control
% Parameters
La = 2E-3;
Ra = 10;
Ja = 3E-6;
cPhiF = .05;

% =================
% Magnitude Optimum
% =================
a_0 = cPhiF;
a_1 = Ja*Ra/cPhiF;
a_2 = Ja*La/cPhiF;

p_0 = a_0*(a_1^2 - a_0*a_2)/(a_1*a_2);
p_1 = a_1/a_0*p_0 - a_0;

% =================
% Symmetric Optimum
% =================
% Controller parameters
K = 1/cPhiF;
s1 = .5*(-Ra/La + sqrt((Ra/La)^2 - 4*cPhiF^2/La/Ja));
s2 = .5*(-Ra/La - sqrt((Ra/La)^2 - 4*cPhiF^2/La/Ja));
T1 = -1/s1;
tau = -1/s2;
T_P = 4*tau;
K_P = 1/(2*K*tau)*T1/(4*tau);


% =======================================
% Simulation
% =======================================
% Magnitude Optimum
u_ref = 1;
r = 20;
M_L = 0;
options = simset('MaxStep',0.0001);
sim('ECE441_Ex4_solution_simulink',[0,.02],options);
figure(1);
plot(t,y_mag,'k');
grid;
hold on;
xlabel('time [sec]')
ylabel('Angular velocity [rad/sec]')
% disturbance rejection
u_ref = 0;
r = 0; 
M_L = 1E-3;
sim('ECE441_Ex4_solution_simulink',[0,.02],options);
figure(2);
plot(t,y_mag,'k');
grid;
hold on;
xlabel('time [sec]')
ylabel('Angular velocity [rad/sec]')
figure(3);
plot(t,u_mag,'k');
grid;
hold on;
xlabel('time [sec]')
ylabel('input [V]')


% Symmetric Optimum
u_ref = 1;
r = 20;
M_L = 0;
options = simset('MaxStep',0.0001);
sim('ECE441_Ex4_solution_simulink',[0,.02],options);
figure(1);
plot(t,y_sym,'b--');
xlabel('time [sec]')
ylabel('Angular velocity [rad/sec]')
legend('Magnitude Optimum','Symmetric Optimum');
% disturbance rejection
u_ref = 0;
r = 0; 
M_L = 1E-3;
sim('ECE441_Ex4_solution_simulink',[0,.02],options);
figure(2);
plot(t,y_sym,'b--');
xlabel('time [sec]')
ylabel('Angular velocity [rad/sec]')
legend('Magnitude Optimum','Symmetric Optimum');
figure(3);
plot(t,u_sym,'b--');
xlabel('time [sec]')
ylabel('input [V]')
legend('Magnitude Optimum','Symmetric Optimum');